@@ -8,10 +8,11 @@ import pandas as pd
 import pytest as pytest
 from fuzzywuzzy import fuzz
 from fuzzywuzzy import process
-from pyannotators_spacyner.spacyner import SpacyNERAnnotator, SpacyNERParameters, get_nlp
 from pybel.parser import BELParser
 from pymultirole_plugins.v1.schema import Document, DocumentList, Sentence
 
+from pyannotators_spacyner.spacyner import SpacyNERAnnotator, SpacyNERParameters
+
 
 def test_spacyner():
     model = SpacyNERAnnotator.get_model()
@@ -21,7 +22,7 @@ def test_spacyner():
     parameters = SpacyNERParameters()
     docs: List[Document] = annotator.annotate([Document(
         text="Paris is the capital of France and Emmanuel Macron is the president of the French Republic.",
-        metadata=parameters.dict())], parameters)
+        metadata={'language': 'en'})], parameters)
     doc0 = docs[0]
     assert len(doc0.annotations) == 4
     paris = doc0.annotations[0]
@@ -39,22 +40,14 @@ def test_scispacyner():
     model_class = model.construct().__class__
     assert model_class == SpacyNERParameters
     annotator = SpacyNERAnnotator()
-    parameters = SpacyNERParameters(model='en_core_sci_sm')
+    parameters = SpacyNERParameters(model_type='sci')
     docs: List[Document] = annotator.annotate([Document(
         text="Myeloid derived suppressor cells (MDSC) are immature myeloid cells with immunosuppressive activity.\nThey accumulate in tumor-bearing mice and humans with different types of cancer, including hepatocellular carcinoma (HCC).",
-        metadata=parameters.dict())], parameters)
+        metadata={'language': 'en'})], parameters)
     doc0 = docs[0]
     assert len(doc0.annotations) == 12
 
 
-def test_cached_nlp():
-    parameters1 = SpacyNERParameters()
-    nlp1, linker1 = get_nlp(parameters1.model)
-    parameters2 = SpacyNERParameters()
-    nlp2, linker2 = get_nlp(parameters2.model)
-    assert id(nlp1) == id(nlp2)
-
-
 def to_camel_case(s):
     return s[0].lower() + string.capwords(s, sep='_').replace('_', '')[1:] if s else s
 
@@ -93,7 +86,7 @@ def test_scai_parse():
 @pytest.mark.skip(reason="Not a test")
 def test_scai():
     annotator = SpacyNERAnnotator()
-    parameters = SpacyNERParameters(model='en_core_sci_sm', scispacy_linker='umls',
+    parameters = SpacyNERParameters(model_type='sci', scispacy_linker='umls',
                                     types_filter=','.join(
                                         ['T028', 'T116', 'T123', 'T126', 'T043', 'T047', 'T121', 'T109',
                                          'T026', 'T025', 'T129', 'T192', 'T044', 'T048', 'T043', 'T131',
